pub struct BlockEntityTicker {
block_entity_type: BlockEntityTypeRef,
tick: fn(&Arc<World>, BlockPos, BlockStateId, &dyn BlockEntity),
}Expand description
Erased block-state-selected ticker for one concrete block-entity type.
Vanilla obtains this callback from the owning block behavior. Keeping the expected type with the callback preserves that selection boundary while allowing Steel’s world ticker to store heterogeneous entries.
Fields
block_entity_type: BlockEntityTypeReftick: fn(&Arc<World>, BlockPos, BlockStateId, &dyn BlockEntity)Implementations
Sourceimpl BlockEntityTicker
impl BlockEntityTicker
Sourcepub const fn new(
block_entity_type: BlockEntityTypeRef,
tick: fn(&Arc<World>, BlockPos, BlockStateId, &dyn BlockEntity),
) -> Self
pub const fn new( block_entity_type: BlockEntityTypeRef, tick: fn(&Arc<World>, BlockPos, BlockStateId, &dyn BlockEntity), ) -> Self
Creates a ticker for one block-entity type.
Sourcepub const fn for_entity_tick(block_entity_type: BlockEntityTypeRef) -> Self
pub const fn for_entity_tick(block_entity_type: BlockEntityTypeRef) -> Self
Creates a state-selected ticker that dispatches to BlockEntity::tick.
Sourcepub fn for_matching_entity_tick(
actual: BlockEntityTypeRef,
expected: BlockEntityTypeRef,
) -> Option<Self>
pub fn for_matching_entity_tick( actual: BlockEntityTypeRef, expected: BlockEntityTypeRef, ) -> Option<Self>
Creates the default entity callback only when Vanilla’s requested type matches.
Sourcepub fn accepts(self, block_entity_type: BlockEntityTypeRef) -> bool
pub fn accepts(self, block_entity_type: BlockEntityTypeRef) -> bool
Returns whether this ticker accepts the concrete block-entity type.
pub(crate) fn tick( self, world: &Arc<World>, pos: BlockPos, state: BlockStateId, block_entity: &dyn BlockEntity, )
fn tick_entity( world: &Arc<World>, _pos: BlockPos, _state: BlockStateId, block_entity: &dyn BlockEntity, )